@@ -1,3 +1,26 @@
+#
+# MIT License
+#
+# Copyright (c) 2023 Mike Heddes, Igor Nunes, Pere Vergés, Denis Kleyko, and Danny Abraham
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+#
 import os
 import os.path
 from typing import Callable, Optional, NamedTuple, List
@@ -16,6 +39,20 @@ class BeijingAirQualityDataSample(NamedTuple):
 class BeijingAirQuality(data.Dataset):
     """`Beijing Multi-Site Air-Quality <https://archive.ics.uci.edu/ml/datasets/Beijing+Multi-Site+Air-Quality+Data>`_ dataset.
 
+    .. list-table::
+       :widths: 10 10 10 10
+       :align: center
+       :header-rows: 1
+
+       * - Instances
+         - Attributes
+         - Task
+         - Area
+       * - 420768
+         - 18
+         - Regression
+         - Physical
+
     .. warning::
         The data contains NaN values that need to be taken into account.
 
@@ -27,6 +64,7 @@ class BeijingAirQuality(data.Dataset):
         download (bool, optional): If true, downloads the dataset from the internet and
             puts it in root directory. If dataset is already downloaded, it is not
             downloaded again.
+
     """
 
     wind_directions: List[str]
@@ -111,7 +149,6 @@ class BeijingAirQuality(data.Dataset):
         return False
 
     def _load_data(self):
-
         files = os.listdir(self.root)
         csv_files = [file for file in files if file.endswith(".csv")]
 
@@ -140,14 +177,14 @@ class BeijingAirQuality(data.Dataset):
         # Map the wind directions to a category identifier (int)
         # # Save the mapping for user referencing
         self.wind_directions = tuple(sorted(list(set(data.wind_direction))))
-        data.loc[:, "wind_direction"] = data.wind_direction.apply(
+        data.wind_direction = data.wind_direction.apply(
             lambda x: self.wind_directions.index(x)
         )
 
         # Map the stations to a category identifier (int)
         # Save the mapping for user referencing
         self.stations = tuple(sorted(list(set(data.station))))
-        data.loc[:, "station"] = data.station.apply(lambda x: self.stations.index(x))
+        data.station = data.station.apply(lambda x: self.stations.index(x))
 
         categorical = data[self.categorical_columns]
         self.categorical_data = torch.tensor(categorical.values, dtype=torch.long)
